@@ -160,7 +160,7 @@ License along with this program.  If not, see
       settings = self.get_settings()
 
       self.path_entry = gtk.Entry()
-      path_button = gtk.Button("Open")
+      path_button = gtk.Button("Browse")
       self.view_entry = gtk.Entry()
       self.edit_entry = gtk.Entry()
 
@@ -237,7 +237,7 @@ License along with this program.  If not, see
          return None
 
       dialog.destroy()
-      self.settings.path_entry.set_text(path)
+      self.path_entry.set_text(path)
 
 # Settings Dialog entry callback
 
